@@ -1,8 +1,12 @@
 import os
 import shutil
 from datetime import datetime
+import typer
+
+app = typer.Typer()
 
 
+@app.command()
 def shipper(tag):
     try:
         lines = []
@@ -34,3 +38,7 @@ def shipper(tag):
         print(datetime.now(), ':: finished')
     except Exception as error:
         print(error)
+
+
+if __name__ == '__main__':
+    app()
